/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.eclipse.sphinx.jdt.util;

import java.io.File;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
import org.eclipse.jdt.core.IClasspathEntry;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jdt.core.JavaCore;

@SuppressWarnings("all")
public class JavaExtensions {
  public static File getFile(final IClasspathEntry entry) {
    File _xifexpression = null;
    IPath _path = entry.getPath();
    File _file = _path.toFile();
    boolean _exists = _file.exists();
    if (_exists) {
      IPath _path_1 = entry.getPath();
      _xifexpression = _path_1.toFile();
    } else {
      IWorkspace _workspace = ResourcesPlugin.getWorkspace();
      IWorkspaceRoot _root = _workspace.getRoot();
      IPath _location = _root.getLocation();
      IPath _path_2 = entry.getPath();
      IPath _append = _location.append(_path_2);
      _xifexpression = _append.toFile();
    }
    return _xifexpression;
  }
  
  public static IJavaProject getJavaProject(final String projectName) {
    IWorkspace _workspace = ResourcesPlugin.getWorkspace();
    IWorkspaceRoot _root = _workspace.getRoot();
    IProject _project = _root.getProject(projectName);
    return JavaCore.create(_project);
  }
  
  /**
   * Returns the absolute path in the local file system corresponding to given workspace-relative path.
   * 
   * @param workspacePath the workspace-relative path to some resource in the workspace
   * 
   * @return the absolute path in the local file system corresponding to given <code>workspacePath</code>, or null if no path can be determined
   */
  public static IPath getLocation(final IPath workspacePath) {
    IWorkspace _workspace = ResourcesPlugin.getWorkspace();
    IWorkspaceRoot _root = _workspace.getRoot();
    IResource _findMember = _root.findMember(workspacePath);
    IPath _location = null;
    if (_findMember!=null) {
      _location=_findMember.getLocation();
    }
    return _location;
  }
}
